-------------------------------------------------------------------------------
--   OCO Source Materials
--
--   Licensed Materials - Property of IBM
--
--   5724-C02
--
--   (C) Copyright IBM Corp. 2003  All Rights Reserved.
--
--   US Government Users Restricted Rights - Use, duplication or
--   disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-------------------------------------------------------------------------------
--    File Information: %W%
--    Revision: %I%
--    Date: %G% %U%
-------------------------------------------------------------------------------
-------------------------------------------------------------------------------
-- TMTP 5.2 Warehouse Pack Fix Pack 2 After Script
-- Please change _user to be the TEDW admin user
-------------------------------------------------------------------------------
connect to twh_cdw user _user;
commit;

-------------------------------------------------------------------------------
-- NEW RELATION TYPES
-------------------------------------------------------------------------------
-- create a temporary table for relation types
-------------------------------------------------------------------------------
DECLARE GLOBAL TEMPORARY TABLE BWM_RelnTyp (
       RelnTyp_Cd           CHAR(6) NOT NULL,
       RelnTyp_Nm           VARCHAR(120) NOT NULL,
       MSrc_Corr_Cd         CHAR(6) NOT NULL
)
WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED
;

insert into session.BWM_RelnTyp values ('ROOTTR', 'Root Transaction Relation', 'MODEL1');
insert into session.BWM_RelnTyp values ('DESCRI', 'Described monitoring of Relation', 'MODEL1');

-------------------------------------------------------------------------------------------
-- insert the relation type into the CDW
-------------------------------------------------------------------------------------------
insert into TWG.RelnTyp
select
 m.RelnTyp_Cd as RelnTyp_Cd,
 m.RelnTyp_Nm as RelnTyp_Nm,
 m.MSrc_Corr_Cd as MSrc_Corr_Cd
from
 session.BWM_RelnTyp m
where
 not exists
( select 1 from
  TWG.RelnTyp t
  where
  t.RelnTyp_Cd = m.RelnTyp_Cd
  )
;

-------------------------------------------------------------------------------
-- NEW RELATION RULES
-------------------------------------------------------------------------------
-- create a temporary table for relation rules
-------------------------------------------------------------------------------
DECLARE GLOBAL TEMPORARY TABLE BWM_RelnRul (
       CompTyp_Source_Cd    CHAR(17) NOT NULL,
       CompTyp_Target_Cd    CHAR(17) NOT NULL,
       RelnTyp_Cd           CHAR(6) NOT NULL,
       RelnRul_Strt_DtTm    TIMESTAMP NOT NULL,
       RelnRul_End_DtTm     TIMESTAMP NOT NULL
)
WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED
;

insert into session.BWM_RelnRul values ('J2EE_SERVER', 'BWM_HOST', 'RUNSON' , CURRENT TIMESTAMP - CURRENT TIMEZONE, '9999-01-01-00.00.00.000000');
insert into session.BWM_RelnRul values ('BWM_TX_NODE','BWM_TX_NODE','ROOTTR', CURRENT TIMESTAMP - CURRENT TIMEZONE, '9999-01-01-00.00.00.000000');

-------------------------------------------------------------------------------------------
-- insert the relation rule into the CDW
-------------------------------------------------------------------------------------------
insert into TWG.RelnRul
select
 m.CompTyp_Source_Cd as CompTyp_Source_Cd,
 m.CompTyp_Target_Cd as CompTyp_Target_Cd,
 m.RelnTyp_Cd as RelnTyp_Cd,
 m.RelnRul_Strt_DtTm as RelnRul_Strt_DtTm,
 m.RelnRul_End_DtTm as RelnRul_End_DtTm
from
 session.BWM_RelnRul m
where
 not exists
( select 1 from
  TWG.RelnRul t
  where
  t.CompTyp_Source_Cd = m.CompTyp_Source_Cd and
  t.CompTyp_Target_Cd = m.CompTyp_Target_Cd and
  t.RelnTyp_Cd = m.RelnTyp_Cd
  )
;

-------------------------------------------------------------------------------
-- Set attribute BWM_PT_CDW_ID to have multiple values
-------------------------------------------------------------------------------
Update TWG.AttrRul
   SET AttrTyp_multi_Val = 'Y' 
   WHERE CompTyp_Cd = 'BWM_TX_NODE' and
         AttrTyp_Cd = 'BWM_PT_CDW_ID';

--------------------------------------------------------------------------------------------
-- 1: Expire components
--------------------------------------------------------------------------------------------

UPDATE TWG.Comp
SET comp_end_dttm = CURRENT TIMESTAMP - CURRENT TIMEZONE
WHERE comptyp_cd = 'J2EE_SERVER'
      AND comp_nm = '.*'
;

UPDATE TWG.Comp
SET comp_end_dttm = CURRENT TIMESTAMP - CURRENT TIMEZONE
WHERE comptyp_cd IN ('J2EE_DOMAIN','J2EE_NODE','J2EE_CELL')
      AND comp_nm = 'N/A'
;

--------------------------------------------------------------------------------------------
-- 2: Relate
--------------------------------------------------------------------------------------------

INSERT INTO TWG.CompReln (Compreln_id, comp_source_id, comp_target_id, relntyp_cd, compreln_strt_dttm, compreln_end_dttm, MSrc_Corr_Cd)
SELECT DISTINCT
    0 AS Compreln_id,
    creln1.comp_target_id AS comp_source_id,
    creln2.comp_target_id AS comp_target_id,
    'RUNSON' AS relntyp_cd,
    CURRENT TIMESTAMP - CURRENT TIMEZONE  AS comp_start_dttm,
   '9999-01-01-00.00.00.000000' AS compreln_end_dttm,
   'BWM' as MSrc_Corr_Cd
FROM
    TWG.cur_compReln creln1,
    TWG.cur_compReln creln2,
    TWG.cur_comp c1,
    TWG.cur_comp c2,
    TWG.cur_comp c3
WHERE
    c1.comp_id = creln1.comp_source_ID AND
    c1.comp_id = creln2.comp_source_id AND
    c2.comp_id = creln1.comp_target_id AND
    c3.comp_id = creln2.comp_target_id AND
    c1.comptyp_Cd = 'BWM_TX_NODE' AND
    c2.comptyp_Cd = 'J2EE_SERVER' AND
    c3.comptyp_Cd IN ('BWM_HOST', 'IP_HOST') AND
    creln1.relntyp_cd = 'USES' AND
    creln2.relntyp_cd = 'RUNSON' AND
    NOT EXISTS(
    SELECT 1 FROM TWG.cur_compreln creln3
    WHERE
       creln1.comp_target_id = creln3.comp_source_id AND
       creln2.comp_target_id = creln3.comp_target_id AND
       creln3.relntyp_cd='RUNSON'
    )
;


